@@ -1,53 +1,60 @@
-sub DMARC_DNS_ERROR_NO_RECORD();
+sub DMARC_POLICY_NONE();
 sub DMARC_DNS_ERROR_NXDOMAIN();
+sub MAXPATHLEN();
 sub DMARC_DNS_ERROR_TMPERR();
-sub DMARC_FROM_DOMAIN_ABSENT();
 sub DMARC_MAXHOSTNAMELEN();
-sub DMARC_PARSE_ERROR_BAD_DKIM_MACRO();
-sub DMARC_PARSE_ERROR_BAD_SPF_MACRO();
-sub DMARC_PARSE_ERROR_BAD_VALUE();
+sub DMARC_POLICY_SPF_OUTCOME_FAIL();
+sub DMARC_RECORD_FO_1();
+sub DMARC_RECORD_RF_AFRF();
+sub DMARC_RECORD_A_STRICT();
+sub DMARC_POLICY_SPF_ORIGIN_HELO();
+sub DMARC_RECORD_A_RELAXED();
+sub MAXNS();
+sub DMARC_TLD_ERROR_UNKNOWN();
 sub DMARC_PARSE_ERROR_BAD_VERSION();
+sub DMARC_POLICY_DKIM_OUTCOME_FAIL();
 sub DMARC_PARSE_ERROR_EMPTY();
-sub DMARC_PARSE_ERROR_NO_ALLOC();
-sub DMARC_PARSE_ERROR_NO_DOMAIN();
-sub DMARC_PARSE_ERROR_NO_REQUIRED_P();
+sub OPENDMARC_LIB_VERSION();
+sub DMARC_FROM_DOMAIN_ABSENT();
 sub DMARC_PARSE_ERROR_NULL_CTX();
+sub DMARC_RECORD_P_QUARANTINE();
+sub DMARC_RECORD_RF_IODEF();
+sub DMARC_POLICY_DKIM_OUTCOME_PASS();
+sub DMARC_POLICY_QUARANTINE();
+sub DMARC_RECORD_P_NONE();
+sub DMARC_POLICY_DKIM_ALIGNMENT_PASS();
+sub DMARC_RECORD_FO_UNSPECIFIED();
+sub DMARC_RECORD_P_UNSPECIFIED();
+sub OPENDMARC_TLD_TYPE_NONE();
+sub DMARC_POLICY_SPF_OUTCOME_NONE();
+sub DMARC_POLICY_SPF_OUTCOME_TMPFAIL();
 sub DMARC_PARSE_OKAY();
+sub DMARC_POLICY_SPF_OUTCOME_PASS();
+sub OPENDMARC_TLD_TYPE_MOZILLA();
+sub DMARC_PARSE_ERROR_BAD_SPF_MACRO();
+sub DMARC_POLICY_SPF_ALIGNMENT_FAIL();
+sub OPENDMARC_MAX_NSADDRLIST();
+sub DMARC_DNS_ERROR_NO_RECORD();
+sub DMARC_PARSE_ERROR_NO_ALLOC();
+sub DMARC_RECORD_A_UNSPECIFIED();
+sub DMARC_PARSE_ERROR_NO_DOMAIN();
+sub DMARC_RECORD_FO_S();
+sub DMARC_RECORD_FO_D();
+sub DMARC_POLICY_IP_TYPE_IPV6();
+sub DMARC_PARSE_ERROR_NO_REQUIRED_P();
+sub DMARC_POLICY_SPF_ORIGIN_MAILFROM();
+sub DMARC_RECORD_FO_0();
 sub DMARC_POLICY_ABSENT();
 sub DMARC_POLICY_DKIM_ALIGNMENT_FAIL();
-sub DMARC_POLICY_DKIM_ALIGNMENT_PASS();
-sub DMARC_POLICY_DKIM_OUTCOME_FAIL();
-sub DMARC_POLICY_DKIM_OUTCOME_NONE();
-sub DMARC_POLICY_DKIM_OUTCOME_PASS();
-sub DMARC_POLICY_DKIM_OUTCOME_TMPFAIL();
-sub DMARC_POLICY_IP_TYPE_IPV4();
-sub DMARC_POLICY_IP_TYPE_IPV6();
-sub DMARC_POLICY_NONE();
-sub DMARC_POLICY_PASS();
-sub DMARC_POLICY_QUARANTINE();
-sub DMARC_POLICY_REJECT();
-sub DMARC_POLICY_SPF_ALIGNMENT_FAIL();
-sub DMARC_POLICY_SPF_ALIGNMENT_PASS();
-sub DMARC_POLICY_SPF_ORIGIN_HELO();
-sub DMARC_POLICY_SPF_ORIGIN_MAILFROM();
-sub DMARC_POLICY_SPF_OUTCOME_FAIL();
-sub DMARC_POLICY_SPF_OUTCOME_NONE();
-sub DMARC_POLICY_SPF_OUTCOME_PASS();
-sub DMARC_POLICY_SPF_OUTCOME_TMPFAIL();
-sub DMARC_RECORD_A_RELAXED();
-sub DMARC_RECORD_A_STRICT();
-sub DMARC_RECORD_A_UNSPECIFIED();
-sub DMARC_RECORD_P_NONE();
-sub DMARC_RECORD_P_QUARANTINE();
-sub DMARC_RECORD_P_REJECT();
-sub DMARC_RECORD_P_UNSPECIFIED();
-sub DMARC_RECORD_RF_AFRF();
-sub DMARC_RECORD_RF_IODEF();
 sub DMARC_RECORD_RF_UNSPECIFIED();
-sub DMARC_TLD_ERROR_UNKNOWN();
-sub OPENDMARC_LIB_VERSION();
-sub OPENDMARC_MAX_NSADDRLIST();
-sub OPENDMARC_TLD_TYPE_MOZILLA();
-sub OPENDMARC_TLD_TYPE_NONE();
+sub DMARC_POLICY_PASS();
+sub DMARC_POLICY_DKIM_OUTCOME_TMPFAIL();
+sub DMARC_POLICY_DKIM_OUTCOME_NONE();
+sub DMARC_POLICY_IP_TYPE_IPV4();
+sub DMARC_POLICY_SPF_ALIGNMENT_PASS();
+sub DMARC_PARSE_ERROR_BAD_DKIM_MACRO();
+sub DMARC_PARSE_ERROR_BAD_VALUE();
+sub DMARC_RECORD_P_REJECT();
+sub DMARC_POLICY_REJECT();
 
 1;
